<?php

// Display errors for debugging during development
ini_set('display_errors', 1);
error_reporting(E_ALL);

// Include necessary files
require_once 'dbconn.php'; // Database connection
require_once 'fpdf.php'; // PDF generation library
require 'sendemail/src/Exception.php';
require 'sendemail/src/PHPMailer.php';
require 'sendemail/src/SMTP.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Generate a unique Request Form No
function generateRequestFormNo($db) {
    $prefix = "VMSW-" . date('Ym');
    $code = sprintf("%'.04d", 1);
    
    while (true) {
        $check = $db->query("SELECT COUNT(*) as count FROM walkin_visitors WHERE request_form_no = '{$prefix}{$code}'")->fetch_assoc()['count'];
        if ($check > 0) {
            $code = sprintf("%'.04d", intval(substr($code, -4)) + 1);
        } else {
            break;
        }
    }
    return $prefix . $code;
}

// Send email function
function sendEmail($mail, $recipient, $subject, $body, $attachment = null, $ccRecipient = null) {
    try {
        $mail->setFrom('farzana@umedichealthcare.com', 'UMedic Healthcare');
        $mail->addAddress($recipient);
        if ($ccRecipient) {
            $mail->addCC($ccRecipient);
        }
        $mail->Subject = $subject;
        $mail->isHTML(true);
        $mail->Body = "<html><body>{$body}</body></html>";
        if ($attachment) {
            $mail->addAttachment($attachment);
        }
        return $mail->send();
    } catch (Exception $e) {
        error_log("Error sending email: " . $e->getMessage());
        return false;
    } finally {
        $mail->clearAddresses();
    }
}

// Generate PDF with visitor details and QR code
function generatePDF($visitor) {
    $pdf = new FPDF();
    $pdf->AddPage();
    $pdf->SetFont('Arial', 'B', 14);
    $pdf->Cell(0, 10, "Visitor Pass for Walk-In", 0, 1, 'C');
    $pdf->Ln(10);

    $pdf->SetFont('Arial', '', 12);
    
    // Output visitor details as Name: value, Email: value, etc.
    $pdf->Cell(90, 10, "" . htmlspecialchars($visitor['request_form_no']), 0, 1);
    $pdf->Cell(90, 10, "Name: " . htmlspecialchars($visitor['name']), 0, 1);
    $pdf->Cell(90, 10, "Email: " . htmlspecialchars($visitor['email']), 0, 1);
    $pdf->Cell(90, 10, "Phone No: " . htmlspecialchars($visitor['phone']), 0, 1);
    $pdf->Cell(90, 10, "Visitor Type: " . htmlspecialchars($visitor['visitor_type']), 0, 1);
    $pdf->Cell(90, 10, "Meeting Room: " . htmlspecialchars($visitor['meeting_room']), 0, 1);
    $pdf->Cell(90, 10, "Visit Date & Time: " . htmlspecialchars($visitor['visit_date']), 0, 1);

    // Generate QR code from visitor data
    $qrData = "https://visitor.umedic.com.my/visitor?id=" . urlencode($visitor['request_form_no']);
    $qrCodeUrl = "https://api.qrserver.com/v1/create-qr-code/?size=100x100&data=" . urlencode($qrData);
    $qrCodeFile = tempnam(sys_get_temp_dir(), 'qr_') . '.png';
    file_put_contents($qrCodeFile, file_get_contents($qrCodeUrl));
    
    // Add QR code image to PDF
    $pdf->Image($qrCodeFile, 150, $pdf->GetY() - 50, 40, 40);  // Position QR code
    unlink($qrCodeFile); // Clean up the temporary QR code file

    // Output PDF to file
    $pdfDirectory = 'public_html/vms/pdfs/';
    if (!file_exists($pdfDirectory)) {
        mkdir($pdfDirectory, 0777, true);
    }
    $pdfFilePath = $pdfDirectory . $visitor['request_form_no'] . '.pdf';
    $pdf->Output('F', $pdfFilePath);

    return $pdfFilePath;
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = $_POST['name'];
    $email = $_POST['email'];
    $phone = $_POST['phone'];
    $visitor_type = $_POST['visitor_type'];
    $meeting_room = $_POST['meeting_room'];
    $visit_date = $_POST['visit_date'];

    // Generate unique Request Form No
    $request_form_no = generateRequestFormNo($db);

    // Insert visitor data into the database
    $stmt = $db->prepare("INSERT INTO walkin_visitors (request_form_no, name, email, phone, visitor_type, meeting_room, visit_date) VALUES (?, ?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("sssssss", $request_form_no, $name, $email, $phone, $visitor_type, $meeting_room, $visit_date);
    if ($stmt->execute()) {
        // Populate visitor array with data
        $visitor = [
            'request_form_no' => $request_form_no,
            'name' => $name,
            'email' => $email,
            'phone' => $phone,
            'visitor_type' => $visitor_type,
            'meeting_room' => $meeting_room,
            'visit_date' => $visit_date
        ];

        // Generate PDF for the walk-in visitor
        $pdfFilePath = generatePDF($visitor);

        // Prepare email details
        $subject = "Walk-In Visitor Registration";
        $body = "
            <html>
                <body style='font-family: Arial, sans-serif; font-size: 14px; color: #333;'>
                    <p>Dear {$name},<br><br>Your walk-in visit has been registered successfully. Here are the details:</p>
                    <ul>
                        <li><strong>Request Form No:</strong> {$request_form_no}</li>
                        <li><strong>Name:</strong> {$name}</li>
                        <li><strong>Email:</strong> {$email}</li>
                        <li><strong>Phone:</strong> {$phone}</li>
                        <li><strong>Visitor Type:</strong> {$visitor_type}</li>
                        <li><strong>Meeting Room:</strong> {$meeting_room}</li>
                        <li><strong>Date & Time:</strong> {$visit_date}</li>
                    </ul>
                    <p>Please bring this pass with you when you arrive.</p>
                    <p style='margin-top: 20px; font-size: 12px; color: #888;'>Thank you,</p>
                    <p style='font-weight: bold;'>UMedic Healthcare</p>
                </body>
            </html>
        ";

        // Set up PHPMailer and send email with the generated PDF attached
        $mail = new PHPMailer(true);
        $mail->isSMTP();
        $mail->Host = 'mail.umedichealthcare.com';
        $mail->SMTPAuth = true;
        $mail->Username = 'farzana@umedichealthcare.com';
        $mail->Password = '385003&+Umc';
        $mail->SMTPSecure = 'ssl';
        $mail->Port = 465;

        if (sendEmail($mail, $email, $subject, $body, $pdfFilePath)) {
            // Redirect to a thank-you page if the email is sent successfully
            header('Location: thank_you1.php');
            exit;
        } else {
            echo "Failed to send email.";
        }
    } else {
        echo "Failed to save visitor details.";
    }
}
?>
